MalCat
======

MalCat is a Python kit for developing CSS generators for MyAnimeList.net. It provides simple and functional utilities
for accessing users' list data and formatting them as text.


Installation
------------

.. code:: bash

    $ pip install malcat


Contents
--------

MalCat includes 3 packages for list retrieval and processing:

- malcat: List processing.
- malcat.legacy: Sample implementations of previous CSS generators.
    - malcat.legacy.malcat
    - malcat.legacy.malgen
- myanimelist: MyAnimeList API layer for list retrieval.
